@@ -80,6 +80,18 @@ as_nodelist.tbl_graph <- function(.data) {
   dplyr::tibble(data.frame(out))
 }
 
+# Changelists ####
+
+#' @rdname manip_as
+#' @export
+as_changelist <- function(.data) UseMethod("as_changelist")
+
+#' @export
+as_changelist.tbl_graph <- function(.data) {
+  out <- igraph::graph_attr(as_igraph(.data), "changes")
+  dplyr::tibble(data.frame(out))
+}
+
 # Edgelists ####
 
 #' @rdname manip_as
@@ -334,8 +346,9 @@ as_igraph.data.frame <- function(.data,
   if (inherits(.data, "tbl_df")) .data <- as.data.frame(.data)
   # Warn if no column named weight and weight set to true
   if (is_weighted(.data) & !("weight" %in% names(.data))) {
-    names(.data)[3] <- "weight"
-    # cli::cli_abort("Please rename the weight column of your dataframe to 'weight'")
+    if(!names(.data)[3] %in% c("begin","sign","date"))
+      names(.data)[3] <- "weight"
+    # snet_abort("Please rename the weight column of your dataframe to 'weight'")
   }
   if (!is_labelled(.data)) {
     graph <- igraph::graph_from_data_frame(.data,
@@ -474,10 +487,35 @@ as_igraph.network.goldfish <- function(.data,
     out <- igraph::graph_from_data_frame(d = get(attr(.data, "events"))[,2:4],
                                          directed = attr(.data, "directed"),
                                          vertices = get(attr(.data, "nodes")))
-  } else cli::cli_abort("Non-empty starts are not yet supported by this function.")
+  } else snet_abort("Non-empty starts are not yet supported by this function.")
   out
 }
 
+#' @export
+as_igraph.networkDynamic <- function(.data, twomode = FALSE) {
+  
+  # edges
+  out <- do.call(rbind, lapply(.data$mel, function(x) 
+    data.frame(x$outl, x$inl, x$atl$active)))
+  names(out) <- c("from","to","begin","end")
+  out <- as.data.frame(out)
+  
+  # nodes
+  nodes <- do.call(rbind, lapply(.data$val, 
+                                 function(x) x[!names(x) %in% c("na","active")]))
+  nodes <- as.data.frame(nodes)
+  names(nodes) <- gsub("vertex.names", "name", names(nodes))
+  
+  out <- igraph::graph_from_data_frame(out, vertices = nodes)
+  
+  # changes
+  changes <- do.call(rbind, lapply(1:length(.data$val), 
+                                   function(x) data.frame(x, .data$val[[x]]$active)))
+  names(changes) <- c("node","begin","end")
+  
+  as_igraph(add_changes(out, changes))
+}
+
 #' @export
 as_igraph.siena <- function(.data, twomode = NULL) {
   edges <- orig <- .get_rem_time_periods <- .get_all_time_periods <- NULL
@@ -629,8 +667,8 @@ as_tidygraph.list <- function(.data, twomode = FALSE) {
     } else if ("nodes" %in% names(.data) & "edges" %in% names(.data)) {
       out <- tidygraph::tbl_graph(nodes = .data[["nodes"]],
                            edges = .data[["edges"]])
-    } else cli::cli_abort("Please name the list elements 'nodes' and 'ties'.")
-  } else cli::cli_abort("Please name the list elements 'nodes' and 'ties'.")
+    } else snet_abort("Please name the list elements 'nodes' and 'ties'.")
+  } else snet_abort("Please name the list elements 'nodes' and 'ties'.")
   make_mnet(out)
 }
   
@@ -680,7 +718,7 @@ as_tidygraph.network.goldfish <- function(.data,
                                          directed = attr(.data, "directed"),
                                          vertices = get(attr(.data, "nodes")))
     out <- as_tidygraph(out)
-  } else cli::cli_abort("Non-empty starts are not yet supported by this function.")
+  } else snet_abort("Non-empty starts are not yet supported by this function.")
 
   # if(rowSums(classes)['network.goldfish']>1){
   #   nets <- colnames(classes)[classes['network.goldfish', ]==TRUE]
@@ -724,6 +762,11 @@ make_mnet <- function(out){
   out
 }
 
+#' @export
+as_tidygraph.networkDynamic <- function(.data, twomode = FALSE) {
+  as_tidygraph(as_igraph.networkDynamic(.data, twomode = twomode))
+}
+
 # Network ####
 
 #' @rdname manip_as
@@ -942,10 +985,11 @@ as_graphAM.network.goldfish <- function(.data, twomode = NULL) {
 #' @importFrom dplyr tibble
 #' @examples
 #'   # How to create a diff_model object from (basic) observed data
-#'   events <- data.frame(t = c(0,1,1,2,3), 
-#'                        nodes = c(1,2,3,2,4), 
-#'                        event = c("I","I","I","R","I"))
-#'   as_diffusion(create_filled(4), events = events)
+#'   events <- data.frame(time = c(0,1,1,2,3), 
+#'                        node = c(1,2,3,2,4),
+#'                        var = "diffusion", 
+#'                        value = c("I","I","I","R","I"))
+#'   add_changes(create_filled(4), events)
 #' @export
 as_diffusion <- function(.data, twomode = FALSE, events) UseMethod("as_diffusion")
 
@@ -954,6 +998,47 @@ as_diffusion.diff_model <- function(.data, twomode = FALSE, events) {
   .data
 }
 
+#' @export
+as_diffusion.mnet <- function(.data, twomode = FALSE, events) {
+  events <- as_changelist(.data)
+  nodes <- net_nodes(.data)
+  sumchanges <- events %>% dplyr::group_by(time) %>% 
+    dplyr::reframe(I_new = sum(value == "I"),
+                   E_new = sum(value == "E"),
+                   R_new = sum(value == "R"))
+  report <- dplyr::tibble(time = seq_len(max(events$time)) - 1,
+                          n = nodes) %>% 
+    dplyr::left_join(sumchanges, by = dplyr::join_by(time))
+  report[is.na(report)] <- 0
+  report$R <- cumsum(report$R_new)
+  report$I <- cumsum(report$I_new) - report$R
+  report$E <- ifelse(report$E_new == 0 & 
+                       cumsum(report$E_new) == max(cumsum(report$E_new)),
+                     report$E_new, cumsum(report$E_new))
+  report$E <- ifelse(report$R + report$I + report$E > report$n,
+                     report$n - (report$R + report$I),
+                     report$E)
+  report$S <- report$n - report$R - report$I - report$E
+  report$s <- vapply(report$time, function(t){
+    twin <- dplyr::filter(events, events$time <= t)
+    infected <- dplyr::filter(twin, twin$value == "I")$node
+    recovered <- dplyr::filter(twin, twin$value == "R")$node
+    infected <- setdiff(infected, recovered)
+    expos <- node_is_exposed(.data, infected)
+    expos[recovered] <- F
+    sum(expos)
+  }, numeric(1) )
+  if (any(report$R + report$I + report$E + report$S != report$n)) {
+    snet_abort("Oops, something is wrong")
+  }
+  report <- dplyr::select(report, 
+                          dplyr::any_of(c("time", "n", "S", "s", "E", "E_new", 
+                                          "I", "I_new", "R", "R_new")))
+  # make_diff_model(events, report, .data)
+  class(report) <- c("diff_model", class(report))
+  report
+}
+
 #' @export
 as_diffusion.igraph <- function(.data, twomode = FALSE, events) {
   net <- as_tidygraph(.data)
@@ -985,7 +1070,7 @@ as_diffusion.igraph <- function(.data, twomode = FALSE, events) {
     sum(expos)
   }, numeric(1) )
   if (any(report$R + report$I + report$E + report$S != report$n)) {
-    cli::cli_abort("Oops, something is wrong")
+    snet_abort("Oops, something is wrong")
   }
   report <- dplyr::select(report, dplyr::any_of(c("t", "n", "S", "s", "E", "E_new", "I", "I_new", "R", "R_new")))
   make_diff_model(events, report, .data)
@@ -1032,7 +1117,7 @@ as_diffusion.diffnet <- function(.data, twomode = FALSE, events) {
     sum(expos)
   }, numeric(1) )
   if (any(report$R + report$I + report$E + report$S != report$n)) {
-    cli::cli_abort("Oops, something is wrong")
+    snet_abort("Oops, something is wrong")
   }
   if(is_labelled(net)) events$nodes <- match(events$nodes, node_names(net))
   events <- events %>% dplyr::arrange(t)
@@ -1060,6 +1145,7 @@ as_diffnet.diff_model <- function(.data,
       out$nodes <- node_names(as_igraph(.data))[out$nodes]
   toa <- stats::setNames(out$t, out$nodes)
   if(is_dynamic(.data)){
+    snet_unavailable()
     # netdiffuseR::igraph_to_diffnet(graph.list = to_waves(.data))
   } else {
     graph <- as_tidygraph(.data) %>% mutate(toa = as.numeric(toa)) %>% as_igraph()
