@@ -55,8 +55,6 @@ NULL
 #' @examples
 #' to_mode1(ison_southern_women)
 #' to_mode2(ison_southern_women)
-#' #graphr(to_mode1(ison_southern_women))
-#' #graphr(to_mode2(ison_southern_women))
 #' @export
 to_mode1 <- function(.data, similarity = c("count","jaccard","rand","pearson","yule")) UseMethod("to_mode1")
 
@@ -161,7 +159,6 @@ to_mode2.data.frame <- function(.data, similarity = c("count","jaccard","rand","
 #' @importFrom igraph make_line_graph E
 #' @examples
 #' to_ties(ison_adolescents)
-#' #graphr(to_ties(ison_adolescents))
 #' @export
 to_ties <- function(.data) UseMethod("to_ties")
 
@@ -252,7 +249,8 @@ to_no_missing <- function(.data) UseMethod("to_no_missing")
 
 #' @export
 to_no_missing.tbl_graph <- function(.data){
-  delete_nodes(.data, !stats::complete.cases(as_nodelist(.data)))
+  delete_nodes(.data, !stats::complete.cases(as_nodelist(.data))) %>% 
+    add_info(name = paste(net_name(.data), "without nodes with missing data"))
 }
 
 
@@ -346,7 +344,8 @@ to_giant.network <- function(.data) {
 
 #' @export
 to_giant.tbl_graph <- function(.data) {
-  as_tidygraph(to_giant(as_igraph(.data)))
+  as_tidygraph(to_giant(as_igraph(.data))) %>% 
+    add_info(name = paste(net_name(.data, prefix = "Giant component of")))
 }
 
 #' @export
@@ -374,7 +373,9 @@ to_no_isolates <- function(.data) UseMethod("to_no_isolates")
 to_no_isolates.tbl_graph <- function(.data) {
   nodes <- NULL
   # Delete edges not present vertices
-  .data %>% tidygraph::activate(nodes) %>% dplyr::filter(!tidygraph::node_is_isolated())
+  .data %>% tidygraph::activate(nodes) %>% 
+    dplyr::filter(!tidygraph::node_is_isolated()) %>% 
+    add_info(name = paste(net_name(.data), "without isolates"))
 }
 
 #' @export
@@ -571,7 +572,7 @@ NULL
 #' 
 #'   Goldberg, Andrew V., and Robert E. Tarjan. 1986. 
 #'   "A new approach to the maximum flow problem". 
-#'   _Proceedings of the eighteenth annual ACM symposium on Theory of computing – STOC '86_. 
+#'   _Proceedings of the 18th Annual ACM Symposium on Theory of Computing_. 
 #'   136-146. 
 #'   \doi{10.1145/12130.12144}
 #' @param mark A logical vector marking two types or modes.
@@ -582,9 +583,9 @@ NULL
 #' @importFrom igraph max_bipartite_match
 #' @examples 
 #' to_matching(ison_southern_women)
-#' #graphr(to_matching(ison_southern_women))
 #' @export
-to_matching <- function(.data, mark = "type", capacities = NULL) UseMethod("to_matching")
+to_matching <- function(.data, mark = "type", 
+                        capacities = NULL) UseMethod("to_matching")
 
 #' @export
 to_matching.igraph <- function(.data, mark = "type", capacities = NULL){
@@ -594,8 +595,10 @@ to_matching.igraph <- function(.data, mark = "type", capacities = NULL){
     el <- igraph::max_bipartite_match(.data, 
                                       types = node_attribute(.data, mark))$matching
     el <- data.frame(from = names(el), to = el)
-    out <- suppressWarnings(as_igraph(el, twomode = TRUE))
-    out <- igraph::delete_vertices(out, "NA")
+    el$from[is.na(el$from)] <- "dummy"
+    el$to[is.na(el$to)] <- "dummy"
+    out <- as_igraph(el, twomode = TRUE)
+    out <- igraph::delete_vertices(out, "dummy")
     out <- to_twomode(out, node_attribute(.data, mark))
   } else {
     if(length(capacities) == 1) 
@@ -646,7 +649,8 @@ to_matching.igraph <- function(.data, mark = "type", capacities = NULL){
 
 #' @export
 to_matching.tbl_graph <- function(.data, mark = "type", capacities = NULL){
-  as_tidygraph(to_matching.igraph(.data, mark, capacities = capacities))
+  as_tidygraph(to_matching.igraph(.data, mark, capacities = capacities)) %>% 
+    add_info(name = paste(net_name(.data, prefix = "Stable matching of")))
 }
 
 #' @export
@@ -684,14 +688,13 @@ to_matching.matrix <- function(.data, mark = "type", capacities = NULL){
 #' "Accelerating the Diffusion of Innovations Using Opinion Leaders",
 #' _Annals of the American Academy of Political and Social Science_ 566: 56-67.
 #' \doi{10.1177/000271629956600105}
-#' @examples
-#' graphr(to_mentoring(ison_adolescents))
 #' @export
 to_mentoring <- function(.data, elites = 0.1) UseMethod("to_mentoring")
 
 #' @export
 to_mentoring.tbl_graph <- function(.data, elites = 0.1){
-  as_tidygraph(to_mentoring.igraph(.data, elites = elites))
+  as_tidygraph(to_mentoring.igraph(.data, elites = elites)) %>% 
+    add_info(name = paste(net_name(.data), "mentorship"))
 }
 
 #' @export
@@ -744,7 +747,6 @@ to_mentoring.igraph <- function(.data, elites = 0.1){
 #' \doi{10.1007/BF01442866}
 #' @examples
 #'   to_eulerian(delete_nodes(ison_koenigsberg, "Lomse"))
-#'   #graphr(to_eulerian(delete_nodes(ison_koenigsberg, "Lomse")))
 #' @export
 to_eulerian <- function(.data) UseMethod("to_eulerian")
 
@@ -765,7 +767,8 @@ to_eulerian.tbl_graph <- function(.data){
   out <- paste(attr(igraph::eulerian_path(.data)$vpath, "names"), 
                collapse = "-+")
   out <- create_explicit(out)
-  out
+  out %>% 
+    add_info(name = paste(net_name(.data, prefix = "Eulerian path of")))
 }
 
 #' @rdname manip_paths 
