@@ -28,12 +28,12 @@ tidygraph::.E
 
 expect_nodes <- function() {
   if (!tidygraph::.graph_context$free() && tidygraph::.graph_context$active() != "nodes") {
-    cli::cli_abort("This call requires nodes to be active", call. = FALSE)
+    snet_abort("This call requires nodes to be active", call. = FALSE)
   }
 }
 
 expect_edges <- function() {
   if (!tidygraph::.graph_context$free() && tidygraph::.graph_context$active() != "edges") {
-    cli::cli_abort("This call requires ties to be active", call. = FALSE)
+    snet_abort("This call requires ties to be active", call. = FALSE)
   }
 }
